@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-help.c 6406 2008-08-13 20:04:04Z pborelli $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,6 +40,7 @@
 #include "gedit-commands.h"
 #include "gedit-debug.h"
 #include "gedit-help.h"
+#include "gedit-dirs.h"
 
 void
 _gedit_cmd_help_contents (GtkAction   *action,
@@ -58,7 +59,8 @@ _gedit_cmd_help_about (GtkAction   *action,
 		"Paolo Maggi <paolo@gnome.org>",
 		"Paolo Borelli <pborelli@katamail.com>",
 		"Steve Fr\303\251cinaux  <steve@istique.net>",
-		"Jesse van den Kieboom  <jesse@icecrew.nl>",
+		"Jesse van den Kieboom  <jessevdk@gnome.org>",
+		"Ignacio Casal Quinteiro <icq@gnome.org>",
 		"James Willcox <jwillcox@gnome.org>",
 		"Chema Celorio",
 		"Federico Mena Quintero <federico@novell.com>",
@@ -74,18 +76,27 @@ _gedit_cmd_help_about (GtkAction   *action,
 	static const gchar copyright[] = \
 		"Copyright \xc2\xa9 1998-2000 Evan Lawrence, Alex Robert\n"
 		"Copyright \xc2\xa9 2000-2002 Chema Celorio, Paolo Maggi\n"
-		"Copyright \xc2\xa9 2003-2006 Paolo Maggi";
+		"Copyright \xc2\xa9 2003-2006 Paolo Maggi\n"
+		"Copyright \xc2\xa9 2004-2010 Paolo Borelli, Jesse van den Kieboom\nSteve Fr\303\251cinaux, Ignacio Casal Quinteiro";
 
 	static const gchar comments[] = \
 		N_("gedit is a small and lightweight text editor for the "
 		   "GNOME Desktop");
 
 	GdkPixbuf *logo;
+	gchar *data_dir;
+	gchar *logo_file;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	logo = gdk_pixbuf_new_from_file (GEDIT_DATADIR "/logo/gedit-logo.png",
-					 NULL);
+	data_dir = gedit_dirs_get_gedit_data_dir ();
+	logo_file = g_build_filename (data_dir,
+				      "logo",
+				      "gedit-logo.png",
+				      NULL);
+	g_free (data_dir);
+	logo = gdk_pixbuf_new_from_file (logo_file, NULL);
+	g_free (logo_file);
 
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "program-name", "gedit",
