@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin-manager.c 6774 2009-01-01 12:41:37Z icq $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -783,31 +783,26 @@ static void
 gedit_plugin_manager_init (GeditPluginManager *pm)
 {
 	GtkWidget *label;
-	GtkWidget *alignment;
 	GtkWidget *viewport;
 	GtkWidget *hbuttonbox;
-	gchar *markup;
 
 	gedit_debug (DEBUG_PLUGINS);
 
 	pm->priv = GEDIT_PLUGIN_MANAGER_GET_PRIVATE (pm);
 
+	/*
+	 * Always we create the manager, firstly we rescan the plugins directory
+	 */
+	gedit_plugins_engine_rescan_plugins (gedit_plugins_engine_get_default ());
+
 	gtk_box_set_spacing (GTK_BOX (pm), 6);
 
-	label = gtk_label_new (NULL);
-	markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
-					  _("Active plugins"));
-	gtk_label_set_markup (GTK_LABEL (label), markup);
-	g_free (markup);
+	label = gtk_label_new_with_mnemonic (_("Active _Plugins:"));
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	
 	gtk_box_pack_start (GTK_BOX (pm), label, FALSE, TRUE, 0);
 	
-	alignment = gtk_alignment_new (0., 0., 1., 1.);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-	gtk_box_pack_start (GTK_BOX (pm), alignment, TRUE, TRUE, 0);
-	
 	viewport = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (viewport),
 					GTK_POLICY_AUTOMATIC,
@@ -815,11 +810,13 @@ gedit_plugin_manager_init (GeditPluginManager *pm)
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (viewport), 
 					     GTK_SHADOW_IN);
 
-	gtk_container_add (GTK_CONTAINER (alignment), viewport);
+	gtk_box_pack_start (GTK_BOX (pm), viewport, TRUE, TRUE, 0);
 
 	pm->priv->tree = gtk_tree_view_new ();
 	gtk_container_add (GTK_CONTAINER (viewport), pm->priv->tree);
 
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pm->priv->tree);
+
 	hbuttonbox = gtk_hbutton_box_new ();
 	gtk_box_pack_start (GTK_BOX (pm), hbuttonbox, FALSE, FALSE, 0);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
