@@ -43,7 +43,6 @@
 #include "gedit-progress-message-area.h"
 #include "gedit-debug.h"
 #include "gedit-prefs-manager-app.h"
-#include "gedit-convert.h"
 #include "gedit-enum-types.h"
 
 #if !GTK_CHECK_VERSION (2, 17, 1)
@@ -422,6 +421,17 @@ document_uri_notify_handler (GeditDocument *document,
 	g_object_notify (G_OBJECT (tab), "name");
 }
 
+static void 
+document_shortname_notify_handler (GeditDocument *document,
+				   GParamSpec    *pspec,
+				   GeditTab      *tab)
+{
+	gedit_debug (DEBUG_TAB);
+	
+	/* Notify the change in the shortname */
+	g_object_notify (G_OBJECT (tab), "name");
+}
+
 static void
 document_modified_changed (GtkTextBuffer *document,
 			   GeditTab      *tab)
@@ -468,76 +478,57 @@ static void
 io_loading_error_message_area_response (GtkWidget        *message_area,
 					gint              response_id,
 					GeditTab         *tab)
-{
-	if (response_id == GTK_RESPONSE_OK)
-	{
-		GeditDocument *doc;
-		gchar *uri;
-
-		doc = gedit_tab_get_document (tab);
-		g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-
-		uri = gedit_document_get_uri (doc);
-		g_return_if_fail (uri != NULL);
-
-		set_message_area (tab, NULL);
-		gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING);
-
-		g_return_if_fail (tab->priv->auto_save_timeout <= 0);
-
-		gedit_document_load (doc,
-				     uri,
-				     tab->priv->tmp_encoding,
-				     tab->priv->tmp_line_pos,
-				     FALSE);
-	}
-	else
-	{
-		remove_tab (tab);
-	}
-}
-
-static void 
-conversion_loading_error_message_area_response (GtkWidget        *message_area,
-						gint              response_id,
-						GeditTab         *tab)
 {
 	GeditDocument *doc;
+	GeditView *view;
 	gchar *uri;
+	const GeditEncoding *encoding;
 
 	doc = gedit_tab_get_document (tab);
 	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 
+	view = gedit_tab_get_view (tab);
+	g_return_if_fail (GEDIT_IS_VIEW (view));
+
 	uri = gedit_document_get_uri (doc);
 	g_return_if_fail (uri != NULL);
 
-	if (response_id == GTK_RESPONSE_OK)
+	switch (response_id)
 	{
-		const GeditEncoding *encoding;
+		case GTK_RESPONSE_OK:
+			encoding = gedit_conversion_error_message_area_get_encoding (
+					GTK_WIDGET (message_area));
 
-		encoding = gedit_conversion_error_message_area_get_encoding (
-				GTK_WIDGET (message_area));
+			if (encoding != NULL)
+			{
+				tab->priv->tmp_encoding = encoding;
+			}
 
-		g_return_if_fail (encoding != NULL);
+			set_message_area (tab, NULL);
+			gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING);
 
-		set_message_area (tab, NULL);
-		gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING);
+			g_return_if_fail (tab->priv->auto_save_timeout <= 0);
 
-		tab->priv->tmp_encoding = encoding;
+			gedit_document_load (doc,
+					     uri,
+					     tab->priv->tmp_encoding,
+					     tab->priv->tmp_line_pos,
+					     FALSE);
+			break;
+		case GTK_RESPONSE_YES:
+			/* This means that we want to edit the document anyway */
+			set_message_area (tab, NULL);
+			_gedit_document_set_readonly (doc, FALSE);
+			break;
+		case GTK_RESPONSE_NO:
+			/* We don't want to edit the document just show it */
+			set_message_area (tab, NULL);
+			break;
+		default:
+			_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), uri);
 
-		g_return_if_fail (tab->priv->auto_save_timeout <= 0);
-
-		gedit_document_load (doc,
-				     uri,
-				     encoding,
-				     tab->priv->tmp_line_pos,
-				     FALSE);
-	}
-	else
-	{
-		_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), uri);
-
-		remove_tab (tab);
+			remove_tab (tab);
+			break;
 	}
 
 	g_free (uri);
@@ -843,7 +834,8 @@ document_loading (GeditDocument *document,
 		  goffset        total_size,
 		  GeditTab      *tab)
 {
-	double et;
+	gdouble et;
+	gdouble total_time;
 
 	g_return_if_fail ((tab->priv->state == GEDIT_TAB_STATE_LOADING) ||
 		 	  (tab->priv->state == GEDIT_TAB_STATE_REVERTING));
@@ -858,39 +850,15 @@ document_loading (GeditDocument *document,
 
 	et = g_timer_elapsed (tab->priv->timer, NULL);
 
-	if (tab->priv->times_called == 1)
-	{
-		if ((total_size == 0) || (total_size > 51200UL) /* 50 KB */)
-		{
-			show_loading_message_area (tab);
-		}
-	}
-	else
-	{
-		if ((tab->priv->times_called == 3) && (total_size != 0))
-		{
-			gdouble total_time;
+	/* et : total_time = size : total_size */
+	total_time = (et * total_size) / size;
 
-			/* et : total_time = size : total_size */
-			total_time = (et * total_size)/size;
-
-			if ((total_time - et) > 3.0)
-			{
-				show_loading_message_area (tab);
-			}
-		}
-		else
-		{
-			if (et > 3.0)
-			{
-				show_loading_message_area (tab);
-			}
-		}
+	if ((total_time - et) > 3.0)
+	{
+		show_loading_message_area (tab);
 	}
-	
+
 	message_area_set_progress (tab, size, total_size);
-
-	tab->priv->times_called++;
 }
 
 static gboolean
@@ -927,7 +895,9 @@ document_loaded (GeditDocument *document,
 	location = gedit_document_get_location (document);
 	uri = gedit_document_get_uri (document);
 
-	if (error != NULL)
+	/* if the error is CONVERSION FALLBACK don't treat it as a normal error */
+	if (error != NULL &&
+	    (error->domain != GEDIT_DOCUMENT_ERROR || error->code != GEDIT_DOCUMENT_ERROR_CONVERSION_FALLBACK))
 	{
 		if (tab->priv->state == GEDIT_TAB_STATE_LOADING)
 			gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING_ERROR);
@@ -936,7 +906,7 @@ document_loaded (GeditDocument *document,
 
 		encoding = gedit_document_get_encoding (document);
 
-		if (error->domain == G_IO_ERROR && 
+		if (error->domain == G_IO_ERROR &&
 		    error->code == G_IO_ERROR_CANCELLED)
 		{
 			/* remove the tab, but in an idle handler, since
@@ -947,14 +917,14 @@ document_loaded (GeditDocument *document,
 
 			goto end;
 		}
-		else if (error->domain == G_IO_ERROR || 
-			 error->domain == GEDIT_DOCUMENT_ERROR)
+		else
 		{
 			_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), uri);
 
 			if (tab->priv->state == GEDIT_TAB_STATE_LOADING_ERROR)
 			{
-				emsg = gedit_io_loading_error_message_area_new (uri, 
+				emsg = gedit_io_loading_error_message_area_new (uri,
+										tab->priv->tmp_encoding,
 										error);
 				g_signal_connect (emsg,
 						  "response",
@@ -965,7 +935,7 @@ document_loaded (GeditDocument *document,
 			{
 				g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_REVERTING_ERROR);
 				
-				emsg = gedit_unrecoverable_reverting_error_message_area_new (uri, 
+				emsg = gedit_unrecoverable_reverting_error_message_area_new (uri,
 											     error);
 
 				g_signal_connect (emsg,
@@ -976,25 +946,6 @@ document_loaded (GeditDocument *document,
 
 			set_message_area (tab, emsg);
 		}
-		else
-		{
-			g_return_if_fail ((error->domain == G_CONVERT_ERROR) ||
-			      		  (error->domain == GEDIT_CONVERT_ERROR));
-
-			// TODO: different error messages if tab->priv->state == GEDIT_TAB_STATE_REVERTING?
-			// note that while reverting encoding should be ok, so this is unlikely to happen
-			emsg = gedit_conversion_error_while_loading_message_area_new (
-									uri,
-									tab->priv->tmp_encoding,
-									error);
-
-			set_message_area (tab, emsg);
-
-			g_signal_connect (emsg,
-					  "response",
-					  G_CALLBACK (conversion_loading_error_message_area_response),
-					  tab);
-		}
 
 #if !GTK_CHECK_VERSION (2, 17, 1)
 		gedit_message_area_set_default_response (GEDIT_MESSAGE_AREA (emsg),
@@ -1025,6 +976,36 @@ document_loaded (GeditDocument *document,
 				   mime);
 		g_free (mime);
 
+		if (error &&
+		    error->domain == GEDIT_DOCUMENT_ERROR &&
+		    error->code == GEDIT_DOCUMENT_ERROR_CONVERSION_FALLBACK)
+		{
+			GtkWidget *emsg;
+
+			_gedit_document_set_readonly (document, TRUE);
+
+			emsg = gedit_io_loading_error_message_area_new (uri,
+									tab->priv->tmp_encoding,
+									error);
+
+			set_message_area (tab, emsg);
+
+			g_signal_connect (emsg,
+					  "response",
+					  G_CALLBACK (io_loading_error_message_area_response),
+					  tab);
+
+#if !GTK_CHECK_VERSION (2, 17, 1)
+			gedit_message_area_set_default_response (GEDIT_MESSAGE_AREA (emsg),
+								 GTK_RESPONSE_CANCEL);
+#else
+			gtk_info_bar_set_default_response (GTK_INFO_BAR (emsg),
+							   GTK_RESPONSE_CANCEL);
+#endif
+
+			gtk_widget_show (emsg);
+		}
+
 		/* Scroll to the cursor when the document is loaded */
 		gedit_view_scroll_to_cursor (GEDIT_VIEW (tab->priv->view));
 
@@ -1101,7 +1082,8 @@ document_saving (GeditDocument    *document,
 		 goffset  total_size,
 		 GeditTab         *tab)
 {
-	double et;
+	gdouble et;
+	gdouble total_time;
 
 	g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_SAVING);
 
@@ -1116,36 +1098,14 @@ document_saving (GeditDocument    *document,
 
 	et = g_timer_elapsed (tab->priv->timer, NULL);
 
-	if (tab->priv->times_called == 1)
-	{
-		if ((total_size == 0) || (total_size > 51200UL) /* 50 KB */)
-		{
-			show_saving_message_area (tab);
-		}
-	}
-	else
-	{
-		if ((tab->priv->times_called == 3) && (total_size != 0))
-		{
-			gdouble total_time;
+	/* et : total_time = size : total_size */
+	total_time = (et * total_size)/size;
 
-			/* et : total_time = size : total_size */
-			total_time = (et * total_size)/size;
-
-			if ((total_time - et) > 3.0)
-			{
-				show_saving_message_area (tab);
-			}
-		}
-		else
-		{
-			if (et > 3.0)
-			{
-				show_saving_message_area (tab);
-			}
-		}
+	if ((total_time - et) > 3.0)
+	{
+		show_saving_message_area (tab);
 	}
-	
+
 	message_area_set_progress (tab, size, total_size);
 
 	tab->priv->times_called++;
@@ -1353,8 +1313,10 @@ document_saved (GeditDocument *document,
 					  G_CALLBACK (no_backup_error_message_area_response),
 					  tab);
 		}
-		else if (error->domain == GEDIT_DOCUMENT_ERROR || 
-			 error->domain == G_IO_ERROR)
+		else if (error->domain == GEDIT_DOCUMENT_ERROR ||
+			 (error->domain == G_IO_ERROR &&
+			  error->code != G_IO_ERROR_INVALID_DATA &&
+			  error->code != G_IO_ERROR_PARTIAL_INPUT))
 		{
 			/* These errors are _NOT_ recoverable */
 			_gedit_recent_remove  (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
@@ -1374,7 +1336,8 @@ document_saved (GeditDocument *document,
 		else
 		{
 			/* This error is recoverable */
-			g_return_if_fail (error->domain == G_CONVERT_ERROR);
+			g_return_if_fail (error->domain == G_CONVERT_ERROR ||
+			                  error->domain == G_IO_ERROR);
 
 			emsg = gedit_conversion_error_while_saving_message_area_new (
 									tab->priv->tmp_save_uri,
@@ -1584,6 +1547,10 @@ gedit_tab_init (GeditTab *tab)
 			  "notify::uri",
 			  G_CALLBACK (document_uri_notify_handler),
 			  tab);
+	g_signal_connect (doc,
+			  "notify::shortname",
+			  G_CALLBACK (document_shortname_notify_handler),
+			  tab);
 	g_signal_connect (doc,
 			  "modified_changed",
 			  G_CALLBACK (document_modified_changed),
@@ -2186,9 +2153,10 @@ gedit_tab_auto_save (GeditTab *tab)
 }
 
 void
-_gedit_tab_save_as (GeditTab            *tab,
-		    const gchar         *uri,
-		    const GeditEncoding *encoding)
+_gedit_tab_save_as (GeditTab                 *tab,
+                    const gchar              *uri,
+                    const GeditEncoding      *encoding,
+                    GeditDocumentNewlineType  newline_type)
 {
 	GeditDocument *doc;
 	GeditDocumentSaveFlags save_flags;
@@ -2233,6 +2201,11 @@ _gedit_tab_save_as (GeditTab            *tab,
 	if (tab->priv->auto_save_timeout > 0)
 		remove_auto_save_timeout (tab);
 
+	/* FIXME: this should behave the same as encoding, setting it here
+	   makes it persistent (if save fails, it's remembered). It's not
+	   a very big deal, but would be nice to have them follow the
+	   same pattern. This can be changed once we break API for 3.0 */
+	gedit_document_set_newline_type (doc, newline_type);
 	gedit_document_save_as (doc, uri, encoding, tab->priv->save_flags);
 }
 
@@ -2846,3 +2819,14 @@ gedit_tab_set_auto_save_interval (GeditTab *tab,
 		install_auto_save_timeout (tab);
 	}
 }
+
+void
+gedit_tab_set_info_bar (GeditTab  *tab,
+                        GtkWidget *info_bar)
+{
+	g_return_if_fail (GEDIT_IS_TAB (tab));
+	g_return_if_fail (info_bar == NULL || GTK_IS_WIDGET (info_bar));
+
+	/* FIXME: this can cause problems with the tab state machine */
+	set_message_area (tab, info_bar);
+}
