@@ -25,16 +25,18 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.h,v 1.7 2006/08/07 16:42:41 pborelli Exp $
+ * $Id$
  */
 
 #ifndef __GEDIT_WINDOW_H__
 #define __GEDIT_WINDOW_H__
 
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 
 #include <gedit/gedit-tab.h>
 #include <gedit/gedit-panel.h>
+#include <gedit/gedit-message-bus.h>
 
 G_BEGIN_DECLS
 
@@ -53,7 +55,6 @@ typedef enum
  */
 #define GEDIT_TYPE_WINDOW              (gedit_window_get_type())
 #define GEDIT_WINDOW(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_WINDOW, GeditWindow))
-#define GEDIT_WINDOW_CONST(obj)        (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_WINDOW, GeditWindow const))
 #define GEDIT_WINDOW_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GEDIT_TYPE_WINDOW, GeditWindowClass))
 #define GEDIT_IS_WINDOW(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GEDIT_TYPE_WINDOW))
 #define GEDIT_IS_WINDOW_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_WINDOW))
@@ -149,9 +150,16 @@ GtkWidget	*gedit_window_get_statusbar		(GeditWindow         *window);
 GtkUIManager	*gedit_window_get_ui_manager		(GeditWindow         *window);
 
 GeditWindowState gedit_window_get_state 		(GeditWindow         *window);
-	
+
+GeditTab        *gedit_window_get_tab_from_location	(GeditWindow         *window,
+							 GFile               *location);
+
 GeditTab        *gedit_window_get_tab_from_uri		(GeditWindow         *window,
 							 const gchar         *uri);
+
+/* Message bus */
+GeditMessageBus	*gedit_window_get_message_bus		(GeditWindow         *window);
+
 /*
  * Non exported functions
  */
@@ -161,12 +169,20 @@ GeditWindow	*_gedit_window_move_tab_to_new_window	(GeditWindow         *window,
 							 GeditTab            *tab);
 gboolean	 _gedit_window_is_removing_tabs		(GeditWindow         *window);
 
-G_CONST_RETURN gchar
-		*_gedit_window_get_default_path 	(GeditWindow         *window);
+GFile		*_gedit_window_get_default_location 	(GeditWindow         *window);
+
+void		 _gedit_window_set_default_location 	(GeditWindow         *window,
+							 GFile               *location);
 
 void		 _gedit_window_set_saving_session_state	(GeditWindow         *window,
 							 gboolean             saving_session);
 
+void		 _gedit_window_fullscreen		(GeditWindow         *window);
+
+void		 _gedit_window_unfullscreen		(GeditWindow         *window);
+
+gboolean	 _gedit_window_is_fullscreen		(GeditWindow         *window);
+
 /* these are in gedit-window because of screen safety */
 void		 _gedit_recent_add			(GeditWindow	     *window,
 							 const gchar         *uri,
