@@ -24,7 +24,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-taglist-plugin.c,v 1.16 2006/07/17 16:50:56 jessevdk Exp $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -81,17 +81,21 @@ impl_activate (GeditPlugin *plugin,
 {
 	GeditPanel *side_panel;
 	GtkWidget *taglist_panel;
+	gchar *data_dir;
 	
 	gedit_debug (DEBUG_PLUGINS);
 	
 	g_return_if_fail (g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY) == NULL);
 	
 	side_panel = gedit_window_get_side_panel (window);
-	taglist_panel = gedit_taglist_plugin_panel_new (window);
+	
+	data_dir = gedit_plugin_get_data_dir (plugin);
+	taglist_panel = gedit_taglist_plugin_panel_new (window, data_dir);
+	g_free (data_dir);
 	
 	gedit_panel_add_item_with_stock_icon (side_panel, 
 					      taglist_panel, 
-					      "Tags", 
+					      _("Tags"), 
 					      GTK_STOCK_ADD);
 
 	g_object_set_data (G_OBJECT (window), 
